pyxmpp2.streamevents.ResolvingAddressEvent

Package pyxmpp2 :: Module streamevents :: Class ResolvingAddressEvent |
[hide private]

# Class ResolvingAddressEvent

Emitted when staring to resolve an address (A or AAAA) DNS record for a hostname.

Probably useful only for connection progres monitoring.

Nested Classes | [hide private]
Inherited from `mainloop.interfaces.Event`: `__metaclass__`

Instance Methods | [hide private]
__init__(self, hostname) x.__init__(...) initializes x; see help(type(x)) for signature |
__unicode__(self) |
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
Inherited from `StreamEvent`: `stream` Inherited from `mainloop.interfaces.Event`: `__abstractmethods__` Inherited from `mainloop.interfaces.Event` (private): `_abc_cache`, `_abc_negative_cache`, `_abc_negative_cache_version`, `_abc_registry`

Instance Variables | [hide private]
`unicode` | hostname host name

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, hostname) (Constructor) |
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)

### __unicode__(self) |
Overrides: mainloop.interfaces.Event.__unicode__